<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>CmdApproxSurface</name>
    <message>
        <source>Reverse Engineering</source>
        <translation>Reverse Engineering</translation>
    </message>
    <message>
        <source>Approximate surface...</source>
        <translation>Flächenapproximation...</translation>
    </message>
    <message>
        <source>Approximate a B-Spline surface</source>
        <translation>Approximiere B-Spline-Fläche</translation>
    </message>
</context>
<context>
    <name>Workbench</name>
    <message>
        <source>Reverse Engineering</source>
        <translation>Reverse Engineering</translation>
    </message>
</context>
</TS>
